from sqlalchemy.orm import Session
from sqlalchemy import func

from models import BookCategoryStatistics, BookCategoryLink


def update_category_statistics(session: Session) -> None:
    """
    Updates category statistics by calculating the count of books in each category.

    :param session: SQLAlchemy session object.
    """
    # Calculate the book count for each category using a query
    category_counts = (
        session.query(
            BookCategoryLink.book_category_id, 
            func.count(BookCategoryLink.book_id).label('book_count')
        )
        .group_by(BookCategoryLink.book_category_id)
        .all()
    )

    # Update or create statistics based on the query results
    for category_id, book_count in category_counts:
        existing_statistics = (
            session.query(BookCategoryStatistics)
            .filter_by(book_category_id=category_id)
            .one_or_none()
        )

        if existing_statistics:
            # Update the existing count
            existing_statistics.book_count = book_count
        else:
            # Create new statistics for the category
            new_statistics = BookCategoryStatistics(
                book_category_id=category_id,
                book_count=book_count
            )
            session.add(new_statistics)


__all__ = ["update_category_statistics"]
