from sqlalchemy import Column, Integer, String, TIMESTAMP, UniqueConstraint, func
from sqlalchemy.orm import relationship

from .base_model import Base


class Author(Base):
    __tablename__ = 'author'
    __table_args__ = (UniqueConstraint('id'),)

    id = Column(Integer, primary_key=True, autoincrement=True)
    first_name = Column(String(50), nullable=False)
    last_name = Column(String(50), nullable=False)
    last_updated = Column(TIMESTAMP, nullable=False, server_default=func.now())

    # Reference 'Book' as a string to avoid direct import
    books = relationship('Book', back_populates='author')

    def to_dict(self):
        return {col.name: getattr(self, col.name) for col in self.__table__.columns}


__all__ = ["Author"]
